@@ -41,7 +41,7 @@
 
 (defun high-surrogate (code)
   (declare (character-code code))
-  (+ #xB800 (- (ldb (byte 11 10) code) #b1000000)))
+  (+ #xD800 (- (ldb (byte 11 10) code) #b1000000)))
 
 ;;;;;;;;;;;;;;;;;;;;;
 ;;; external function
@@ -50,7 +50,7 @@
 
 (defun read (code-stream)
   (declare (code-stream code-stream))
-  (symbol-macrolet ((position (position code-stream))
+  (symbol-macrolet ((position   (position code-stream))
 		    (surrogate? (surrogate? code-stream)))
     (cond (surrogate? 
 	   (setf surrogate? nil)
@@ -70,7 +70,7 @@
 
 (defun unread (code-stream)
   (declare (code-stream code-stream))
-  (symbol-macrolet ((position (position code-stream))
+  (symbol-macrolet ((position   (position code-stream))
 		    (surrogate? (surrogate? code-stream)))
     (if surrogate? 
 	(setf surrogate? nil)
